package com.zipcodewilmington.froilansfarm;

import com.zipcodewilmington.froilansfarm.animals.AnimalHouse;
import com.zipcodewilmington.froilansfarm.animals.Chicken;
import com.zipcodewilmington.froilansfarm.animals.Horse;
import com.zipcodewilmington.froilansfarm.produce.CropRow;
import com.zipcodewilmington.froilansfarm.vehicle.FarmVehicle;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class Farm {
    private List<AnimalHouse<Horse>> stables = new ArrayList<>();
    private List<AnimalHouse<Chicken>> chickenCoops = new ArrayList<>();
    private Field field = new Field();
    private List<FarmVehicle> vehicles = new ArrayList<>();
    private FarmHouse farmHouse;
    private Map<String, List<Edible>> foodPantry = new HashMap<>();


    public void setField(Field field) {
        this.field = field;
    }

    public void setChickenCoop(List<AnimalHouse<Chicken>> chickenCoops) {
        this.chickenCoops = chickenCoops;
    }

    public void setStables(List<AnimalHouse<Horse>> stables) {
        this.stables = stables;
    }

    public void setVehicles(List<FarmVehicle> vehicles) {
        this.vehicles = vehicles;
    }

    public FarmVehicle getVehicle(FarmVehicle.Type type){
        for(FarmVehicle vehicle : vehicles) {
            if (type == vehicle.getType()){
                return vehicle;
            }
        }
        return null;
    }

    public void setFarmHouse(FarmHouse farmHouse) {
        this.farmHouse = farmHouse;
    }

    public FarmHouse getFarmHouse() {
        return farmHouse;
    }

    public void addVehicle(FarmVehicle vehicle){
        vehicles.add(vehicle);
    }

    public int getFoodCount() {
        return foodPantry.size();
    }

    public void addFood(List<Edible> food) {
        for(Edible e : food) {
            getFood(e.getName()).add(e);
        }
    }

    public List<Edible> getFood(String foodName) {
        foodName = foodName.toLowerCase();
        List<Edible> food = foodPantry.get(foodName);
        if(food == null) {
            food = new ArrayList<>();
            foodPantry.put(foodName, food);
        }

        return food;
    }

    public CropRow getCropRow(int rowNumber) {
        return field.getCropRow(rowNumber);
    }

    public Field getField() {
        return field;
    }

    public void addChickenCoop(AnimalHouse<Chicken> coop) {
        chickenCoops.add(coop);
    }

    public List<AnimalHouse<Chicken>> getChickenCoops() {
        return chickenCoops;
    }

    public void addHorseStable(AnimalHouse<Horse> stable) {
        stables.add(stable);
    }

    public List<AnimalHouse<Horse>> getStables() {
        return stables;
    }

    public List<FarmVehicle> getVehicles() {
        return vehicles;
    }
}
