package com.zipcodewilmington.froilansfarm;

import com.zipcodewilmington.froilansfarm.animals.AnimalHouse;
import com.zipcodewilmington.froilansfarm.animals.Chicken;
import com.zipcodewilmington.froilansfarm.animals.Horse;
import com.zipcodewilmington.froilansfarm.produce.CropRow;
import com.zipcodewilmington.froilansfarm.vehicle.FarmVehicle;

import java.util.ArrayList;
import java.util.List;

public class FarmFactory {

    public static Farm createFroilanFarm(){
        Farm farm = new Farm();
        farm.setField(createField());
        farm.setChickenCoop(createChickenCoups());
        farm.setStables(createStables());
        farm.setVehicles(createVehicles());
        return farm;
    }

    private static Field createField() {
        Field field = new Field();
        addCropRows(field);
        return field;
    }

    private static List<FarmVehicle> createVehicles() {
        List<FarmVehicle> vehicles = new ArrayList<FarmVehicle>();
        vehicles.add(new FarmVehicle(FarmVehicle.Type.TRACTOR));
        vehicles.add(new FarmVehicle(FarmVehicle.Type.TRACTOR));
        vehicles.add(new FarmVehicle(FarmVehicle.Type.CROP_DUSTER));
        return vehicles;
    }

    private static List<AnimalHouse<Horse>> createStables() {
        List<AnimalHouse<Horse>> animalHouses = new ArrayList<AnimalHouse<Horse>>();
        for(int i = 0; i < 3; i++) {
            AnimalHouse<Horse> stable = new AnimalHouse<Horse>();
            for(int c = 0; c < 3; c++) {
                stable.add(new Horse("Betsy " + i + " " + c ));
            }
        }
        return animalHouses;
    }

    private static List<AnimalHouse<Chicken>> createChickenCoups() {
        List<AnimalHouse<Chicken>> animalHouses = new ArrayList<AnimalHouse<Chicken>>();
        for(int i = 0; i < 4; i++) {
            AnimalHouse<Chicken> chickenCoup = new AnimalHouse<Chicken>();
            for(int c = 0; c < 4; c++) {
                chickenCoup.add(new Chicken("Chi "  + i + " " + c ));
            }
        }
        return animalHouses;
    }

    private static void addCropRows(Field field) {
        for(int i = 1; i < 6; i++) {
            field.addCropRow(new CropRow(i));
        }
    }
}
