package com.zipcodewilmington.froilansfarm;

import com.zipcodewilmington.froilansfarm.task.Task;

import java.time.DayOfWeek;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

public class Person implements NoiseMaker, Eater {
    private String name;
    private List<Skill> skills;
    private Map<DayOfWeek, List<Task>> tasks;
    private boolean full;

    public Person(String name) {
        this.name = name;
        this.skills = new ArrayList<>();
        this.tasks = new HashMap<>();
    }

    public void eat(Edible edible) {
        edible.eat();
        full = true;
    }

    @Override
    public boolean isFull() {
        return full;
    }

    public String makeNoise() {
        return "speak";
    }

    public String work(DayOfWeek day){
        StringBuilder status = new StringBuilder();
        List<Task> dayTasks = getTasks(day);

        if (dayTasks.size() > 0 ) {
            status.append(name + " \n");
            for(int i = 0; i < dayTasks.size(); i++) {
                Task task = dayTasks.get(i);
                task.work();
                status.append("\t\t" + task.getStatus() + "\n");
            }
        }

        return status.toString();
    }

    public void addSkill(Skill skill) {
        this.skills.add(skill);
    }

    public void addTask(Task task, DayOfWeek day) {
        if (skills.contains(task.getSkill())) {
            List<Task> dayTasks = getTasks(day);
            dayTasks.add(task);
        } else {
            throw new IllegalStateException(name + " does not the "
                    + task.getSkill().getPrettyName() + " to perform the task");
        }

    }

    public List<Task> getTasks(DayOfWeek day) {
        List<Task> dayTask = tasks.get(day);
        if (dayTask == null) {
            dayTask = new ArrayList<>();
            tasks.put(day, dayTask);
        }
        return dayTask;
    }

    public List<Skill> getSkills() {
        return skills;
    }

    public String getName() {
        return name;
    }
}
