package com.zipcodewilmington.froilansfarm;

import com.zipcodewilmington.froilansfarm.produce.CropType;
import com.zipcodewilmington.froilansfarm.task.Task;
import com.zipcodewilmington.froilansfarm.task.TaskFactory;

import java.time.DayOfWeek;

public class PersonFactory {
    protected static final Skill[] FARMING_SKILL = {Skill.RIDE, Skill.PLANT, Skill.FEED, Skill.DRIVE};
    protected static final Skill[] FLYING_SKILL = {Skill.RIDE, Skill.FLY};

    public static Person create(String name, Farm farm){
        if (name.equalsIgnoreCase("froilan")) {
            return createFroilan(farm);
        } else if (name.equalsIgnoreCase("froilanda")) {
            return createFroilanda(farm);
        } else if (name.equalsIgnoreCase("freelan")){
            return createFreelan(farm);
        } else {
            return null;
        }
    }

    private static Person createFroilan(Farm farm) {
        Person froilan = new Person("Froilan");
        addSkills(froilan, FARMING_SKILL);

        Task plantCrop = TaskFactory.createPlantingTask(farm, 1, CropType.CORN_STALK);
        froilan.addTask(plantCrop, DayOfWeek.SUNDAY);
        Task plantCrop2 = TaskFactory.createPlantingTask(farm, 2, CropType.TOMATO_PLANT);
        froilan.addTask(plantCrop2, DayOfWeek.SUNDAY);

        froilan.addTask(TaskFactory.createHarvestTask(farm, 1), DayOfWeek.TUESDAY);
        froilan.addTask(TaskFactory.createHarvestTask(farm, 2), DayOfWeek.TUESDAY);
        froilan.addTask(TaskFactory.createHarvestTask(farm, 3), DayOfWeek.TUESDAY);

        return froilan;
    }

    private static Person createFroilanda(Farm farm) {
        Person froilanda = new Person("Froilanda");
        addSkills(froilanda, FLYING_SKILL);

        froilanda.addTask(TaskFactory.createFertilizeCropRowTask(farm, 1), DayOfWeek.MONDAY);
        froilanda.addTask(TaskFactory.createFertilizeCropRowTask(farm, 2), DayOfWeek.MONDAY);
        froilanda.addTask(TaskFactory.createFertilizeCropRowTask(farm, 3), DayOfWeek.MONDAY);


        return froilanda;
    }

    private static Person createFreelan(Farm farm) {
        Person freelan = new Person("Freelan");
        addSkills(freelan, FARMING_SKILL);
        addSkills(freelan, FLYING_SKILL);

        Task plantCrop = TaskFactory.createPlantingTask(farm, 3, CropType.CORN_STALK);
        freelan.addTask(plantCrop, DayOfWeek.SUNDAY);

        Task plantCrop2 = TaskFactory.createPlantingTask(farm, 4, CropType.TOMATO_PLANT);
        freelan.addTask(plantCrop2, DayOfWeek.TUESDAY);

        freelan.addTask(TaskFactory.createFertilizeCropRowTask(farm, 4), DayOfWeek.WEDNESDAY);

        return freelan;
    }

    private static void addSkills(Person person, Skill[] skills) {
        for(Skill skill : skills) {
            person.addSkill(skill);
        }
    }
}
