package com.zipcodewilmington.froilansfarm.task;

import com.zipcodewilmington.froilansfarm.Edible;
import com.zipcodewilmington.froilansfarm.Farm;
import com.zipcodewilmington.froilansfarm.Skill;
import com.zipcodewilmington.froilansfarm.animals.Animal;
import com.zipcodewilmington.froilansfarm.animals.AnimalHouse;
import com.zipcodewilmington.froilansfarm.produce.Food;

import java.util.ArrayList;
import java.util.List;

public class FeedAnimalTask<T extends Animal> extends Task {
    private final List<Animal> animals = new ArrayList<>();
    private final Food.Type food;
    private final int amountPerAnimal;

    public FeedAnimalTask(Farm farm, List<AnimalHouse<T>> houses, Food.Type food, int amountPerAnimal) {
        super(farm, Skill.FEED);

        for(AnimalHouse<T> house : houses) {
            this.animals.addAll(house.getAnimals());
        }

        this.food = food;
        this.amountPerAnimal = amountPerAnimal;
    }

    @Override
    public void work() {
        List<Edible> foodList = farm.getFood(food.name());
        for(Animal animal : animals) {
            if (foodList.size() > 0) {
                animal.eat(foodList.remove(0));
            }
        }

        completed = true;
    }

    @Override
    public String getStatus() {
        if (completed && animals.size() > 0) {
            return "fed " + animals.size() +  " " + animals.get(0).getType();
        } else {
            return "did not feed any animal";
        }
    }
}
