package com.zipcodewilmington.froilansfarm;

import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

import java.time.DayOfWeek;
import java.util.List;

public class PersonFactoryTest {
    private Farm farm;

    @Before
    public void setup(){
        farm = FarmFactory.createFroilanFarm();
    }

    @Test
    public void testFroilan_forName(){
        Person froilan = PersonFactory.create("froilan", farm);
        Assert.assertEquals("Froilan", froilan.getName());
    }

    @Test
    public void testFroilan_forSkills(){
        Person froilan = PersonFactory.create("froilan", farm);

        Skill[] expectedSkills = {Skill.RIDE, Skill.PLANT, Skill.FEED, Skill.DRIVE};

        List<Skill> froilanSkills = froilan.getSkills();

        for(Skill skill : expectedSkills) {
            Assert.assertTrue(froilanSkills.contains(skill));
        }
    }

    @Test
    public void testFroilan_forTasks(){
        Person froilan = PersonFactory.create("froilan", farm);

        Assert.assertEquals(2, froilan.getTasks(DayOfWeek.SUNDAY).size());
        Assert.assertEquals(3, froilan.getTasks(DayOfWeek.TUESDAY).size());

    }


    @Test
    public void testFroilanda_forName(){
        Person froilan = PersonFactory.create("froilanda", farm);
        Assert.assertEquals("Froilanda", froilan.getName());
    }

    @Test
    public void testFroilanda_forSkills(){
        Person froilan = PersonFactory.create("froilanda", farm);

        Skill[] expectedSkills = {Skill.RIDE, Skill.FLY};

        List<Skill> froilanSkills = froilan.getSkills();

        for(Skill skill : expectedSkills) {
            Assert.assertTrue(froilanSkills.contains(skill));
        }
    }

    @Test
    public void testFroilanda_forTasks(){
        Person froilan = PersonFactory.create("froilanda", farm);

        Assert.assertEquals(3, froilan.getTasks(DayOfWeek.MONDAY).size());
    }


    @Test
    public void testFreelan_forName(){
        Person froilan = PersonFactory.create("freelan", farm);
        Assert.assertEquals("Freelan", froilan.getName());
    }

    @Test
    public void testFreelan_forSkills(){
        Person froilan = PersonFactory.create("freelan", farm);

        Skill[] expectedSkills = {Skill.RIDE, Skill.FLY, Skill.RIDE, Skill.PLANT, Skill.FEED, Skill.DRIVE};

        List<Skill> froilanSkills = froilan.getSkills();

        for(Skill skill : expectedSkills) {
            Assert.assertTrue(froilanSkills.contains(skill));
        }
    }

    @Test
    public void testFreelan_forTasks(){
        Person froilan = PersonFactory.create("freelan", farm);

        Assert.assertEquals(1, froilan.getTasks(DayOfWeek.SUNDAY).size());
        Assert.assertEquals(1, froilan.getTasks(DayOfWeek.TUESDAY).size());
        Assert.assertEquals(1, froilan.getTasks(DayOfWeek.WEDNESDAY).size());
    }

    @Test
    public void testWhenPersonDoesntExist(){
        Assert.assertNull(PersonFactory.create("badname", farm));
    }
}
