package com.zipcodewilmington.froilansfarm;

import com.zipcodewilmington.froilansfarm.animals.Animal;
import com.zipcodewilmington.froilansfarm.animals.Horse;
import com.zipcodewilmington.froilansfarm.produce.CropRow;
import com.zipcodewilmington.froilansfarm.produce.CropType;
import com.zipcodewilmington.froilansfarm.produce.Food;
import com.zipcodewilmington.froilansfarm.task.TaskFactory;
import com.zipcodewilmington.froilansfarm.task.Task;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

import java.time.DayOfWeek;
import java.util.ArrayList;
import java.util.List;

public class PersonTest {

    private Farm farm;
    private CropRow cropRow;
    private Person person;
    private static final DayOfWeek day = DayOfWeek.SUNDAY;
    private Task task;

    @Before
    public void setup(){
        farm = MockFarmFactory.create();
        cropRow = farm.getCropRow(1);
        person = new Person("Freelan");
        task = TaskFactory.createPlantingTask(farm, 1, CropType.TOMATO_PLANT);

    }

    @Test(expected = IllegalStateException.class)
    public void testAddTask_whenUserDoesNotHaveTheSkill(){
        Task task = TaskFactory.createPlantingTask(farm, 1, CropType.CORN_STALK);
        person.addTask(task, day);
    }

    @Test
    public void testAddTask_whenUserHaveTheSkill(){
        Skill skill = Skill.PLANT;
        person.addSkill(skill);

        person.addTask(task, day);

        List<Task> dayTasks = person.getTasks(day);

        Assert.assertTrue(dayTasks.contains(task));
    }

    @Test
    public void testWork_whenThereIsNoWork(){
        String work = person.work(day);
        Assert.assertEquals("", work);
    }

    @Test
    public void testWork_withOneTask(){
        person.addSkill(Skill.PLANT);
        person.addTask(task, day);

        String work = person.work(day);

        String expected = "Freelan \n\t\tplanted 10 tomato plant in row " + cropRow.getRowNumber() + "\n";
        Assert.assertEquals(expected, work);
    }

    @Test
    public void testWork_withMultipleTask(){
        person.addSkill(Skill.RIDE);
        person.addSkill(Skill.FEED);

        List<Animal> animals = new ArrayList<>();
        animals.add(new Horse("Betsy1"));
        animals.add(new Horse("Betsy2"));


        Task rideTask = TaskFactory.createRideAnimalTask(farm, farm.getStables());
        Task feedTask = TaskFactory.createFeedAnimalTask(farm, farm.getStables(), Food.Type.EARCORN, 2);

        person.addTask(rideTask, day);
        person.addTask(feedTask, day);

        String work = person.work(day);

        String expected = "Freelan \n\t\trode 2 Horse\n\t\tfed 2 Horse\n";

        Assert.assertEquals(expected, work);
    }

    @Test
    public void testEat(){
        Assert.assertFalse(person.isFull());

        person.eat(new Food(Food.Type.EGG));
        Assert.assertTrue(person.isFull());
    }

    @Test
    public void testMakeNoise(){
        Assert.assertEquals("speak", person.makeNoise());
    }
}
