package com.zipcodewilmington.froilansfarm.task;

import com.zipcodewilmington.froilansfarm.Edible;
import com.zipcodewilmington.froilansfarm.Farm;
import com.zipcodewilmington.froilansfarm.MockFarmFactory;
import com.zipcodewilmington.froilansfarm.animals.AnimalHouse;
import com.zipcodewilmington.froilansfarm.animals.Chicken;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

import java.util.List;

public class CollectEggTaskTest {
    private Farm farm;

    @Before
    public void setup(){
        farm = MockFarmFactory.create();

        AnimalHouse<Chicken> animalHouse = new AnimalHouse<>();
        Chicken chicken1 = new Chicken("chi1");
        chicken1.fertilize();
        animalHouse.add(chicken1);

        Chicken chicken2 = new Chicken("coop");
        chicken2.fertilize();
        animalHouse.add(chicken2);

        farm.addChickenCoop(animalHouse);
    }

    @Test
    public void testWork(){
        Task task = TaskFactory.createCollectEggTask(farm);
        task.work();

        List<Edible> eggs = farm.getFood("egg");

        Assert.assertEquals(2, eggs.size());
    }

    @Test
    public void testGetStatus_whenTaskIsCompleted(){
        Task task = TaskFactory.createCollectEggTask(farm);
        task.work();

        String actual = task.getStatus();

        String expected = "collected 2 eggs from the chicken coops";

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testGetStatus_whenNoWorkIsDone(){
        Task task = TaskFactory.createCollectEggTask(farm);

        String actual = task.getStatus();

        String expected = "did not collect any egg";

        Assert.assertEquals(expected, actual);
    }

}
