package com.zipcodewilmington.froilansfarm.task;

import com.zipcodewilmington.froilansfarm.Edible;
import com.zipcodewilmington.froilansfarm.Farm;
import com.zipcodewilmington.froilansfarm.MockFarmFactory;
import com.zipcodewilmington.froilansfarm.animals.AnimalHouse;
import com.zipcodewilmington.froilansfarm.animals.Chicken;
import com.zipcodewilmington.froilansfarm.produce.Food;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

import java.util.ArrayList;
import java.util.List;

public class FeedAnimalTaskTest {
    private Farm farm;

    @Before
    public void setup(){
        farm = MockFarmFactory.create();
        List<Edible> food = new ArrayList<>();
        for(int i = 0; i < 100; i++) {
            food.add(new Food(Food.Type.EARCORN));
        }

        farm.addFood(food);
    }


    @Test
    public void testWork(){
        List<AnimalHouse<Chicken>> coops = farm.getChickenCoops();
        Task task = TaskFactory.createFeedAnimalTask(farm, coops, Food.Type.EARCORN, 1);

        task.work();

        for(AnimalHouse<Chicken> house : coops) {
            for(Chicken chicken : house.getAnimals()) {
                Assert.assertTrue(chicken.isFull());
            }
        }
    }

    @Test
    public void testGetStatus_whenWorkIsComplete(){
        List<AnimalHouse<Chicken>> coops = farm.getChickenCoops();
        Task task = TaskFactory.createFeedAnimalTask(farm, coops, Food.Type.EARCORN, 1);

        task.work();

        String expected = "fed 2 Chicken";
        String actual = task.getStatus();

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testGetStatus_whenWorkIsNotDone(){
        List<AnimalHouse<Chicken>> coops = farm.getChickenCoops();
        Task task = TaskFactory.createFeedAnimalTask(farm, coops, Food.Type.EARCORN, 1);

        String expected = "did not feed any animal";
        String actual = task.getStatus();

        Assert.assertEquals(expected, actual);
    }
}
