package com.zipcodewilmington.froilansfarm.task;

import com.zipcodewilmington.froilansfarm.Farm;
import com.zipcodewilmington.froilansfarm.MockFarmFactory;
import com.zipcodewilmington.froilansfarm.animals.AnimalHouse;
import com.zipcodewilmington.froilansfarm.animals.Chicken;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

public class FertilizeChickenTaskTest {

    private Farm farm;
    private Chicken chicken1;
    private Chicken chicken2;

    @Before
    public void setup(){
        farm = MockFarmFactory.create();

        AnimalHouse<Chicken> animalHouse = new AnimalHouse<>();
        chicken1 = new Chicken("chi1");
        animalHouse.add(chicken1);

        chicken2 = new Chicken("coop");
        animalHouse.add(chicken2);

        farm.addChickenCoop(animalHouse);
    }

    @Test
    public void testWork(){
        Task task = TaskFactory.createFertilizeChickenTask(farm);

        task.work();

        Assert.assertTrue(chicken1.isFertilized());
        Assert.assertTrue(chicken2.isFertilized());
    }

    @Test
    public void testGetStatus_whenTaskIsCompleted(){
        Task task = TaskFactory.createFertilizeChickenTask(farm);
        task.work();

        String actual = task.getStatus();

        String expected = "fertilized 4 chickens";

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testGetStatus_whenNoWorkIsDone(){
        Task task = TaskFactory.createFertilizeChickenTask(farm);

        String actual = task.getStatus();

        String expected = "did not fertilize any chicken";

        Assert.assertEquals(expected, actual);
    }
}
