package com.zipcodewilmington.froilansfarm.task;

import com.zipcodewilmington.froilansfarm.Farm;
import com.zipcodewilmington.froilansfarm.MockFarmFactory;
import com.zipcodewilmington.froilansfarm.produce.Crop;
import com.zipcodewilmington.froilansfarm.produce.CropRow;
import com.zipcodewilmington.froilansfarm.produce.CropType;
import com.zipcodewilmington.froilansfarm.vehicle.FarmVehicle;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

public class FertilizeCropRowTaskTest {
    private Farm farm;
    private Crop crop;

    @Before
    public void setup(){
        crop = new Crop(CropType.CORN_STALK);
        farm = MockFarmFactory.create(crop);
        farm.addVehicle(new FarmVehicle(FarmVehicle.Type.CROP_DUSTER));
    }

    @Test
    public void testWork(){
        Task task = TaskFactory.createFertilizeCropRowTask(farm, 1);
        task.work();

        Assert.assertTrue(crop.isFertilized());
    }

    @Test
    public void testGetStatus_beforeDoingAnyWork(){
        Task task = TaskFactory.createFertilizeCropRowTask(farm, 1);
        String actualMessage = task.getStatus();

        String expectedMessage = "did not complete harvesting for row 1";

        Assert.assertEquals(expectedMessage, actualMessage);
    }

    @Test
    public void testGetStatus_whenTaskIsCompleted(){
        Task task = TaskFactory.createFertilizeCropRowTask(farm, 1);
        task.work();

        String actualMessage = task.getStatus();

        String expectedMessage = "flew a crop duster to fertilize crop on row 1";
        Assert.assertEquals(expectedMessage, actualMessage);
    }
}
