package com.zipcodewilmington.froilansfarm.task;

import com.zipcodewilmington.froilansfarm.Farm;
import com.zipcodewilmington.froilansfarm.FarmHouse;
import com.zipcodewilmington.froilansfarm.MockFarmFactory;
import com.zipcodewilmington.froilansfarm.produce.Crop;
import com.zipcodewilmington.froilansfarm.produce.CropRow;
import com.zipcodewilmington.froilansfarm.produce.CropType;
import com.zipcodewilmington.froilansfarm.vehicle.FarmVehicle;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;


public class HarvestTaskTest {
    private Farm farm;

    @Before
    public void setup(){
        Crop crop = new Crop(CropType.CORN_STALK);
        crop.fertilize();

        farm = MockFarmFactory.create(crop);
        farm.addVehicle(new FarmVehicle(FarmVehicle.Type.TRACTOR));
    }

    @Test
    public void testWork(){
        Task task = TaskFactory.createHarvestTask(farm, 1);
        task.work();
        String actualMessage = task.getStatus();
        String expectedMessage = "drove a tractor to harvest crop row 1";

        Assert.assertEquals(expectedMessage, actualMessage);
        Assert.assertEquals(1, farm.getFoodCount());
    }

    @Test
    public void testGetStatus_afterTaskIsComplete(){
        Task task = TaskFactory.createHarvestTask(farm, 1);
        task.work();

        String actualMessage = task.getStatus();

        String expectedMessage = "drove a tractor to harvest crop row 1";

        Assert.assertEquals(expectedMessage, actualMessage);
    }

    @Test
    public void testGetStatus_whenTaskIsNotDone(){
        Task task = TaskFactory.createHarvestTask(farm, 1);

        String actualMessage = task.getStatus();

        String expectedMessage = "did not harvest crop row 1";

        Assert.assertEquals(expectedMessage, actualMessage);
    }
}
