package com.zipcodewilmington.froilansfarm.task;

import com.zipcodewilmington.froilansfarm.Farm;
import com.zipcodewilmington.froilansfarm.MockFarmFactory;
import com.zipcodewilmington.froilansfarm.produce.Crop;
import com.zipcodewilmington.froilansfarm.produce.CropRow;
import com.zipcodewilmington.froilansfarm.produce.CropType;
import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

public class PlantTaskTest {
    private CropRow cropRow;
    private Farm farm;

    @Before
    public void setup(){
        farm = MockFarmFactory.create();
        cropRow = farm.getCropRow(1);
    }

    @Test
    public void testWork(){
        int numberOfCrop = 10;
        Task task = TaskFactory.createPlantingTask(farm, 1, CropType.CORN_STALK);

        task.work();
        Assert.assertEquals(numberOfCrop, cropRow.getNumberOfCrop());
    }

    @Test
    public void testGetStatus_whenTaskIsCompleted(){
        Task task = TaskFactory.createPlantingTask(farm, 1, CropType.CORN_STALK);

        task.work();
        String actual = task.getStatus();
        String expected = "planted 10 corn stalk in row 1";

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void testGetStatus_whenTaskIsNOTDone(){
        Task task = TaskFactory.createPlantingTask(farm, 1, CropType.CORN_STALK);

        String actual = task.getStatus();
        String expected = "did not plant anything";

        Assert.assertEquals(expected, actual);
    }

}
